diff --git a/.gitignore b/.gitignore
index 48ae6679..d31b7bd3 100644
--- a/.gitignore
+++ b/.gitignore
@@ -5,4 +5,5 @@ build/
# Files
package-lock.json
+yarn-error.log
yarn.lock
diff --git a/README.md b/README.md
index 35d9d90c..dc2b02f9 100644
--- a/README.md
+++ b/README.md
@@ -5,8 +5,6 @@
Fast, open and free-to-use new tab page for most modern browsers.
-*This is the code for the extension. If you are looking for the website code, please go [here](https://github.com/TurboMarshmello/muetab.xyz), or for the API docs go [here](https://apidocs.muetab.xyz)*
-
## Features
* Fast and free
* Supports multiple browsers
@@ -44,7 +42,7 @@ Development/Other: Read the [Development](#development) section.
Starting
- -
git clone https://github.com/ohlookitsderpy/Mue (If you don't have Git just go to Clone or
+ -
git clone https://github.com/muetab/mue (If you don't have Git just go to Clone or
download and click Download ZIP)
- Open a terminal and run these commands: (in the Mue directory)
-
yarn (or npm i)
@@ -112,6 +110,8 @@ Once I find a method to do it automatically, I will update this section accordin
[Opera Forum](https://forums.opera.com/topic/25046/how-to-disable-completely-the-speed-dial/14) - Portions of code to add Opera support
+[Google Fonts](https://fonts.google.com/specimen/Lexend+Deca) - Lexend Deca font
+
### Translations
[ohlookitsderpy](https://github.com/ohlookitsderpy) - English (Quotes and Messages)
diff --git a/package.json b/package.json
index 6cbbf278..7c3e6679 100644
--- a/package.json
+++ b/package.json
@@ -1,23 +1,29 @@
{
"name": "mue",
+ "private": true,
"author": "David \"ohlookitsderpy\" Ralph (https://derpyenterprises.org)",
"maintainers": [
"David \"ohlookitsderpy\" Ralph (https://derpyenterprises.org)",
"Alex \"TurboMarshmello\" Sparkes (https://github.com/TurboMarshmello)"
],
"description": "Fast, open and free-to-use new tab page for most modern browsers.",
+ "repository": {
+ "url": "github:muetab/mue"
+ },
+ "homepage": "https://muetab.xyz",
+ "bugs": "https://github.com/muetab/mue/issues/new?assignees=&labels=bug&template=bug-report.md&title=%5BBUG%5D",
"license": "BSD-3-Clause",
- "version": "2.0.1",
+ "version": "0.6.0",
"dependencies": {
- "@material-ui/core": "^4.7.0",
+ "@material-ui/core": "^4.7.2",
"@material-ui/icons": "^4.5.1",
"@muetab/quotes": "^1.0.0",
"react": "^16.12.0",
"react-dom": "^16.12.0",
- "react-scripts": "3.2.0"
+ "react-scripts": "3.3.0"
},
"devDependencies": {
- "eslint": "^6.6.0",
+ "eslint": "^6.7.2",
"node-sass": "^4.13.0"
},
"scripts": {
@@ -35,8 +41,7 @@
],
"development": [
"last 1 chrome version",
- "last 1 firefox version",
- "last 1 safari version"
+ "last 1 firefox version"
]
}
-}
\ No newline at end of file
+}
diff --git a/src/components/Navbar.jsx b/src/components/Navbar.jsx
index fed3a0ad..43964fa8 100644
--- a/src/components/Navbar.jsx
+++ b/src/components/Navbar.jsx
@@ -3,7 +3,7 @@ import RefreshIcon from '@material-ui/icons/Refresh';
import LocalPizzaIcon from '@material-ui/icons/LocalPizza';
import React from 'react';
-export default class Search extends React.Component {
+export default class Navbar extends React.Component {
render() {
return (
diff --git a/src/components/Clock.jsx b/src/components/Clock.jsx
index 2f88b5eb..4264ba0f 100644
--- a/src/components/Clock.jsx
+++ b/src/components/Clock.jsx
@@ -21,7 +21,7 @@ export default class Clock extends React.Component {
date: `${('0' + h).slice(-2)}:${('0' + t.getMinutes()).slice(-2)}`, ampm: h >= 12 ? 'AM' : 'PM'
}); // Set time
- this.timeout = setTimeout(() => this.startTime(), 500); // Update the clock every 500 milliseconds
+ this.timeout = setTimeout(() => this.startTime(), 750); // Update the clock every 750 milliseconds
}
componentDidMount() {